# Changelog

## 1.1.1 (2025-08-27)

Full Changelog: [v1.1.0...v1.1.1](https://github.com/prosights/recreate-sdk-python/compare/v1.1.0...v1.1.1)

### Bug Fixes

* avoid newer type syntax ([eaa9b77](https://github.com/prosights/recreate-sdk-python/commit/eaa9b777802960723f6d1780d14a05715eb9e37f))


### Chores

* **internal:** change ci workflow machines ([4b38a77](https://github.com/prosights/recreate-sdk-python/commit/4b38a7705ebe7a1222b6d6d8b06ce8a4292d7ffa))
* **internal:** update pyright exclude list ([469b3dc](https://github.com/prosights/recreate-sdk-python/commit/469b3dc828342fb937a0201ae000056bdc251954))

## 1.1.0 (2025-08-22)

Full Changelog: [v1.0.3...v1.1.0](https://github.com/prosights/recreate-sdk-python/compare/v1.0.3...v1.1.0)

### Features

* **api:** update via SDK Studio ([d0cb2eb](https://github.com/prosights/recreate-sdk-python/commit/d0cb2eb84adccb52ff60ac877e41df41afe38181))

## 1.0.3 (2025-08-22)

Full Changelog: [v1.0.2...v1.0.3](https://github.com/prosights/recreate-sdk-python/compare/v1.0.2...v1.0.3)

### Chores

* update github action ([d5053f3](https://github.com/prosights/recreate-sdk-python/commit/d5053f35ba955a7e25d25bd5d2cf32b51888671c))

## 1.0.2 (2025-08-12)

Full Changelog: [v1.0.1...v1.0.2](https://github.com/prosights/recreate-sdk-python/compare/v1.0.1...v1.0.2)

### Chores

* **internal:** codegen related update ([94886a3](https://github.com/prosights/recreate-sdk-python/commit/94886a364df2a5a2e0b7ee946b13687d40c52297))
* **internal:** fix ruff target version ([4d0d6c5](https://github.com/prosights/recreate-sdk-python/commit/4d0d6c59c1263dfc9878d04749b5f5ec5dd73cd8))
* **internal:** update comment in script ([236f5cc](https://github.com/prosights/recreate-sdk-python/commit/236f5cc265a0b8a7849933f4dff0c27575c24e41))
* update @stainless-api/prism-cli to v5.15.0 ([bf74c02](https://github.com/prosights/recreate-sdk-python/commit/bf74c023539d4e6337938f011c798d0dee37b573))

## 1.0.1 (2025-08-04)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/prosights/recreate-sdk-python/compare/v1.0.0...v1.0.1)

## 1.0.0 (2025-08-04)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/prosights/recreate-sdk-python/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([f269ac2](https://github.com/prosights/recreate-sdk-python/commit/f269ac257cb9f7aa9a34781b81ba88086f5ff6df))
* update SDK settings ([6d0fbc5](https://github.com/prosights/recreate-sdk-python/commit/6d0fbc591c628d3384fb93089e1092002af86f1f))
